#coding:utf-8
from django.utils.translation import ugettext as _
from m3.helpers import urls
from m3.ui.gears.edit_windows import GearEditWindow
from m3.ui.ext.containers import ExtContainerTable
from m3.ui.ext.fields import ExtHiddenField, ExtStringField, ExtCheckBox, ExtRadio, ExtFileUploadField
from m3.ui.ext.controls import ExtButton
from m3.ui.ext.panels import ExtForm
from m3.ui.ext.windows import ExtEditWindow, ExtDictionaryWindow

# Копипаста из МТР
class DictSimpleEditWindow(GearEditWindow):
    """ Базовое окно для всех справочников """
    def __init__(self, create_new = True, *args, **kwargs):
        super(DictSimpleEditWindow, self).__init__(*args, **kwargs)
        self.frozen_size(430, 123)
        self.modal = True
        self.create_new = create_new

        # Стандартные поля
        self.field_hidden = ExtHiddenField(name = 'id')
        self.field_code = ExtStringField(
            width = 10, label = u'Код', name = 'code',
            anchor = '60%', allow_blank = True)
        self.field_name = ExtStringField(
            width=200, label=u'Наименование',
            name='name', anchor='100%', allow_blank=False)

        self.form.items.extend([
            self.field_hidden,
            self.field_code,
            self.field_name
        ])

    def configure_for_dictpack(self, **k):
        if self.create_new:
            self.title = u'Создание новой записи: ' + k['pack'].title
        else:
            self.title = u'Редактирование записи: ' + k['pack'].title


#===========================================================================
# Формы для редактирования КЛАДР
#===========================================================================
class KLADRGeoEditWindow(DictSimpleEditWindow):
    def __init__(self, *args, **kwargs):
        super(KLADRGeoEditWindow, self).__init__(*args, **kwargs)
        self.frozen_size(430, 280)

        self.field_name.label = u'Улица'
        self.field_code.width = 300
        self.form.items.extend([
            ExtStringField(width = 300, label = u'Сокращение', name = 'socr'),
            ExtStringField(width = 300, label = u'Индекс', name = 'zipcode'),
            ExtStringField(width = 300, label = u'Код ИФНС', name = 'gni'),
            ExtStringField(width = 300, label = u'Код тер.уч. ИФНС', name = 'uno'),
            ExtStringField(width = 300, label = u'Код ОКАТО', name = 'okato'),
            ])
        # Скрытое поля для группы
        self.form.items.append( ExtHiddenField(name = 'parent_id') )


class KLADRStreetEditWindow(DictSimpleEditWindow):
    def __init__(self, *args, **kwargs):
        super(KLADRStreetEditWindow, self).__init__(*args, **kwargs)
        self.frozen_size(430, 320)

        self.field_name.label = u'Геогр.пункт'
        self.field_code.width = 300
        self.form.items.extend([
            ExtStringField(width = 300, label = u'Сокращение', name = 'socr'),
            ExtStringField(width = 300, label = u'Индекс', name = 'zipcode'),
            ExtStringField(width = 300, label = u'Код ИФНС', name = 'gni'),
            ExtStringField(width = 300, label = u'Код тер.уч. ИФНС', name = 'uno'),
            ExtStringField(width = 300, label = u'Код ОКАТО', name = 'okato'),
            ExtStringField(width = 300, label = u'Статус', name = 'status')
        ])
        # Скрытое поле для родительской группы
        self.form.items.append( ExtHiddenField(name = 'parent_id') )


class KLADRDictListWindow(ExtDictionaryWindow):
    """Окно справочника КЛАДРА"""
    def __init__(self, *args, **kwargs):
        super(KLADRDictListWindow, self).__init__(*args, **kwargs)
        self.import_action_url = urls.get_pack_instance('KLADRPack').import_action.get_absolute_url()
        self.template_globals = 'kladr-list-window.js'

    def init_tree_components(self):
        super(KLADRDictListWindow, self).init_tree_components()
        if not hasattr(self, '_components_import'):
            self._components_import = ExtButton(text=_(u'Импорт'),
                                                icon_cls='icon-database-add',
                                                handler='getImportWindow')
            self.tree.top_bar.items.append(self._components_import)


#===========================================================================
# Формы для импортирования КЛАДР
#===========================================================================

class KLADRImportWindow(ExtEditWindow):
    """Окно импортирования КЛАДРа"""
    def __init__(self, submit_url, *args, **kwargs):
        """Инициализация объекта."""
        super(KLADRImportWindow, self).__init__(*args, **kwargs)
        from updater import KLADRUpdater

        self.width, self.height = 440, 180
        self.min_width, self.min_height = self.width, self.height
        self.title = _(u'Обновление справочника КЛАДР')
        self.template_globals = "kladr-import-window.js"
        self.modal = True

        self.form = ExtForm(url=submit_url, file_upload=True)
        self.form.items.append(ExtHiddenField(name="form_confirmed", value=1))

        self.radio_load_type_file = ExtRadio(name="load_type", value=KLADRUpdater.FILE_UPDATE,
                                             label=_(u"Загрузка файла"), checked=True)
        self.radio_load_type_ws = ExtRadio(name="load_type", value=KLADRUpdater.SERVICE_UPDATE,
                                           label=_(u"Загрузка через веб-сервис"))
        self.table_load_type = ExtContainerTable(rows=1, columns=2, title=_(u"Выберите тип загрузки"))
        self.table_load_type.set_item(0, 0, self.radio_load_type_file)
        self.table_load_type.set_item(0, 1, self.radio_load_type_ws)

        self.field_filename = ExtFileUploadField(name='filename', label=_(u'Файл архива'), anchor='100%',
                                                 possible_file_extensions=['7z'], allow_blank=False)
        self.field_clear_before = ExtCheckBox(label=_(u'Очистить'), name='clear_before', anchor='100%', checked=True,
                                              box_label=_(u"(удаление всех записей КЛАДР перед загрузкой)"))
        self.field_update = ExtCheckBox(label=_(u'Обновление'), name='update', anchor='100%', checked=True,
                                        box_label=_(u"(обновление записей КЛАДР без дублирования)"))
        self.button_start = ExtButton(text=_(u'Начать обновление'), handler='submitForm')
        self.button_cancel = ExtButton(text=_(u'Отмена'), name='cancel_btn', handler='cancelForm')

        self.form.items.extend([
            self.table_load_type,
            self.field_filename,
            self.field_clear_before,
            self.field_update
        ])
        self.buttons.extend([
            self.button_start,
            self.button_cancel
        ])